@@ -6,9 +6,11 @@ import getpass
 import inspect
 import io
 import os
+import re
 import sys
 import time
 import traceback
+from operator import itemgetter
 from typing import IO, Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 
 import colorama
@@ -538,6 +540,65 @@ def ask_choice(
     return res
 
 
+def select_choices(
+    *prompt: Token,
+    choices: List[Any],
+    func_desc: Optional[FuncDesc] = None,
+    sort: Optional[bool] = True,
+) -> Any:
+    """
+    Ask the user to select one or multiple from a list of choices,
+    delimited by space, comma or semi colon.
+
+    Will loop until:
+
+        * the user enters a valid selection
+        * or leaves the prompt empty
+
+    In the last case, `None` will be returned
+
+    :param prompt: a list of tokens suitable for :func:`info`
+    :param choices: a list of arbitrary elements
+    :param func_desc: a callable. It will be used to display and
+                sort the list of choices (unless ``sort`` is False)
+                Defaults to the identity function.
+    :param sort: whether to sort the list of choices.
+
+    :return: the selected choice(s).
+
+    """
+    if func_desc is None:
+        func_desc = lambda x: str(x)
+    tokens = get_ask_tokens(prompt)
+    info(*tokens)
+    if sort:
+        choices.sort(key=func_desc)
+    for i, choice in enumerate(choices, start=1):
+        choice_desc = func_desc(choice)
+        info("  ", blue, "%i" % i, reset, choice_desc)
+    keep_asking = True
+    res = None
+    while keep_asking:
+        answer = read_input()
+        if not answer:
+            return None
+        try:
+
+            index = [int(item) for item in re.split(r"; |, |\s |;|,|\s", answer)]
+            index = [x - 1 for x in index]  # convert to true index
+        except ValueError:
+            info("Please enter a valid number")
+            continue
+
+        try:
+            res = list(itemgetter(*index)(choices))
+        except Exception:
+            info("Please enter valid selection number(s)")
+            continue
+
+        return res
+
+
 def ask_yes_no(*question: Token, default: bool = False) -> bool:
     """Ask the user to answer by yes or no"""
     while True:
